==> 0.0.2.tar.gz: ios/Classes/View/YFAdsBannerView.m <==
#import "YFAdsBannerView.h"
#import "YFAdsBannerManager.h"
#import <YFAdsSDK/YFAdBanner.h>

@interface YFAdsBannerView ()<WHFlutterBannerViewDelegate>
@property (nonatomic, strong)  UIView *parentView;
@property (nonatomic, strong)  YFAdsBannerManager *bannerAdManager;
@end

@implementation YFAdsBannerView

- (instancetype)initWithFrame:(CGRect)frame
                    arguments:(NSDictionary *)args
                    eventSink:(FlutterEventSink)flutterEventSink
               viewController:(UIViewController *)viewController{
    if (self = [super init]) {
        _parentView = [[UIView alloc] init];
    }
    _bannerAdManager = [[YFAdsBannerManager alloc] initWithParams:flutterEventSink viewController:viewController];
    _bannerAdManager.flutterBannerDelegate = self;
    [_bannerAdManager showAd:args];
    return self;
}

- (void)handleParentViewClicked:(UITapGestureRecognizer *)recognizer{
    NSLog(@"handleParentViewClicked");
}

/// banner广告点击关闭
- (void)yfBannerViewDislike{
    NSLog(@"yfBannerViewDislike");
    if(!_parentView){
        return;
    }
    [_parentView removeFromSuperview];
}
/// banner广告加载成功
- (void)yfBannerViewLoadSuccess:(UIView *_Nullable)view{
    NSLog(@"yfBannerViewLoadSuccess");
}
///banner广告加载失败
- (void)yfBannerViewLoadFail:(NSString *_Nullable)stringMessage{
    NSLog(@"yfBannerViewLoadFail %@",stringMessage);
}

//渲染成功
- (void)yfBannerViewRenderSuccess:(UIView *_Nullable)view {
    NSLog(@"yfBannerViewRenderSuccess");
    if(!_parentView){
        return;
    }
    NSArray *childViews = [_parentView subviews];
    if(childViews){
        for(UIView *views in childViews){
            [views removeFromSuperview];
        }
    }
    [_parentView addSubview:view];
}

- (UIView*)view {
    return _parentView;
}



@end

==> 0.0.9.tar.gz: ios/Classes/View/YFAdsBannerView.m <==
#import "YFAdsBannerView.h"
#import "YFAdsBannerManager.h"
#import <YFAdsSDK/YFAdBanner.h>

@interface YFAdsBannerView ()<YFFlutterBannerViewDelegate>
@property (nonatomic, strong)  UIView *parentView;
@property (nonatomic, strong)  YFAdsBannerManager *bannerAdManager;
@end

@implementation YFAdsBannerView

- (instancetype)initWithFrame:(CGRect)frame
                    arguments:(NSDictionary *)args
                    eventSink:(FlutterEventSink)flutterEventSink
               viewController:(UIViewController *)viewController{
    if (self = [super init]) {
        _parentView = [[UIView alloc] init];
    }
    self.bannerAdManager = [[YFAdsBannerManager alloc] initWithParams:flutterEventSink viewController:viewController];
    self.bannerAdManager.flutterBannerDelegate = self;
    [self.bannerAdManager loadAd:args];
    return self;
}

- (void)handleParentViewClicked:(UITapGestureRecognizer *)recognizer{
    NSLog(@"handleParentViewClicked");
}

/// banner广告点击关闭
- (void)yfBannerViewDislike{
    NSLog(@"yfBannerViewDislike");
    if(!_parentView){
        return;
    }
    [_parentView removeFromSuperview];
}
/// banner广告加载成功
- (void)yfBannerViewLoadSuccess:(UIView *_Nullable)view{
    NSLog(@"yfBannerViewLoadSuccess");
}
///banner广告加载失败
- (void)yfBannerViewLoadFail:(NSString *_Nullable)stringMessage{
    NSLog(@"yfBannerViewLoadFail %@",stringMessage);
}

//渲染成功
- (void)yfBannerViewRenderSuccess:(UIView *_Nullable)view {
    NSLog(@"yfBannerViewRenderSuccess");
    if(!_parentView){
        return;
    }
    NSArray *childViews = [_parentView subviews];
    if(childViews){
        for(UIView *views in childViews){
            [views removeFromSuperview];
        }
    }
    [_parentView addSubview:view];
}

- (UIView*)view {
    return _parentView;
}



@end
